#!/bin/bash

################################################################
#
#	CAR (Complex Activity Reconition)
#	Installation script for Fedora
#
#	Autor : Jacques Serlan <jacques.serlan@inria.fr>
#
#
#	Change log :
#	- 29/01/2015	Version 1.7 : New CAR DB
#	- 10/12/2014	Version 1.6 : Yum install instead of rpm for repositories
#	- 23/10/2014	Version 1.5 : Removing the yum cache updating
#	- 08/10/2014	Version 1.4 : Adding help parameters
#	- 22/07/2014	Version 1.3 : Remove loggins, cleaning lines
#	- 14/04/2014	Version 1.2 : Adding variables and cleaning lines
#	- 04/04/2014	Version 1.1 : Adding loggins informations
#	- 19/02/2014	Version 1.0 : First version of the script
#
################################################################

Version="1.7"

######################## Help parameter ########################
help()
{
echo -e "\033[0;34mCAR installation script's for Fedora 64bits"
echo -e "Version : $2\n"
echo -e "\033[0;31mThe script must be started with :"
echo -e "- A operate network access to Internet"
echo -e "- An user with administrative rights (root or sudoer)\n"
echo -e "\033[0;34mAny other cases, see http://team.inria.fr/stars/\033[0m"
exit 0 
}
######################## Check system ##########################
if [ $1 != "" ]
then case $1 in
 "-h")
	help $0 $Version;;
 "--help")
	help $0 $Version;;
 *)
	echo -e "`basename $0` : This is not an expected parameter, try -h or --help for help"
	exit 2
 esac
else
######### Check Fedora version
 if [ ! `rpm -E %fedora` -eq 19 ]
 then
  if [ ! `rpm -E %fedora` -eq 17 ];
  then echo -e "\033[1;30mYou try to install this script on Fedora `rpm -E %fedora`\nThis script is only usable on Fedora 19 or 17\033[0m";
  exit
  else
	fedoraVersion=$(rpm -E %fedora)
  fi
 else
	fedoraVersion=$(rpm -E %fedora)
 fi
fi
######### Check Fedora architecture
if [ `uname -i` != x86_64 ]
then echo -e "\033[1;30mSorry, you try to install this script on a non 64 bits system\nPlease run this script on Fedora 17/19 64bits\033[0m";
exit
fi

######################## Initialization ########################
RPM_ARCHIVE=http://www-sop.inria.fr/stars/car-component/rpm-archives
cd /tmp/

######################## CAR install ###########################
echo "***** CAR Install script running *****"

################### Installing repositories ####################

######### RPM Fusion - Free
echo "Repository Activation : RPM Fusion - Free"
/usr/bin/yum -y -q install http://download1.rpmfusion.org/free/fedora/rpmfusion-free-release-$fedoraVersion.noarch.rpm
if [ $? -eq 0 ]
then echo -e "Status : \033[1;32mSuccess\033[0m"
else echo -e "Status : \033[1;31mFailed\033[0m"
fi

######### RPM Fusion - non Free
echo "Repository Activation : RPM Fusion - non Free"
/usr/bin/yum -y -q install http://download1.rpmfusion.org/nonfree/fedora/rpmfusion-nonfree-release-$fedoraVersion.noarch.rpm
if [ $? -eq 0 ]
then echo -e "Status : \033[1;32mSuccess\033[0m"
else echo -e "Status : \033[1;31mFailed\033[0m"
fi

######### PGDG92
echo "Repository Activation : PGDG92"
/usr/bin/yum -y -q install http://yum.postgresql.org/9.2/fedora/fedora-$fedoraVersion-x86_64/pgdg-fedora92-9.2-6.noarch.rpm
if [ $? -eq 0 ]
then echo -e "Status : \033[1;32mSuccess\033[0m"
else echo -e "Status : \033[1;31mFailed\033[0m"
fi

######################## Installing packages ###################

######### Yum cache updating
#echo "YUM Cache : Cache updating"
#/usr/bin/yum -y -q makecache
#if [ $? -eq 0 ]
#then echo -e "Status : \033[1;32mSuccess\033[0m"
#else echo -e "Status : \033[1;31mFailed\033[0m"
#fi

######### OpenNI
echo "RPMs Installing : OpenNI"
/usr/bin/yum -y -q install ${RPM_ARCHIVE}/openni/openni-1.5.4.0-1.fc$fedoraVersion.x86_64.rpm ${RPM_ARCHIVE}/openni/openni-examples-1.5.4.0-1.fc$fedoraVersion.x86_64.rpm ${RPM_ARCHIVE}/openni/openni-primesense-5.1.2.1-1.fc$fedoraVersion.x86_64.rpm
if [ $? -eq 0 ]
then echo -e "Status : \033[1;32mSuccess\033[0m"
else echo -e "Status : \033[1;31mFailed\033[0m"
fi

######### PostgreSQL
echo "RPMs Installing : PostgreSQL"
/usr/bin/yum -y -q install postgresql92 postgresql92-server postgresql92-contrib
if [ $? -eq 0 ]
then echo -e "Status : \033[1;32mSuccess\033[0m"
else echo -e "Status : \033[1;31mFailed\033[0m"
fi

######### OpenCV
echo "RPMs Installing : OpenCV"
/usr/bin/yum -y -q install ${RPM_ARCHIVE}/opencv/opencv-inria-2.4.7-1.fc$fedoraVersion.x86_64.rpm
if [ $? -eq 0 ]
then echo -e "Status : \033[1;32mSuccess\033[0m"
else echo -e "Status : \033[1;31mFailed\033[0m"
fi

######### SUP
echo "RPMs Installing : SUP"
/usr/bin/wget -q http://www-sop.inria.fr/stars/car-component/sup-fc$fedoraVersion-x86_64.tar.bz2
tar --overwrite -xjf sup-fc$fedoraVersion-x86_64.tar.bz2
/usr/bin/yum -y -q install *.rpm
if [ $? -eq 0 ]
then echo -e "Status : \033[1;32mSuccess\033[0m"
else echo -e "Status : \033[1;31mFailed\033[0m"
fi

######### To fix some issues
/usr/bin/yum -y -q install libvpx-devel

######################## Configuration #########################

######### SUP
echo "SUP Configuration : Libraries"

cat > /etc/ld.so.conf.d/inria.conf << EOF
/usr/local/inria/dtk/lib
/usr/local/inria/sup/lib
/usr/local/inria/3party/lib
/usr/local/inria/extra/AnhTuan/lib
/usr/local/inria/extra/MTS/lib
/usr/local/inria/extra/DepthCompression/lib
/usr/local/inria/extra/rleSegmentation/lib
/usr/local/inria/extra/SED/lib
/usr/local/inria/sup/plugins
/usr/local/inria/sup/extralibs/lib
EOF

if [ -f /etc/ld.so.conf.d/inria.conf ]
then /usr/sbin/ldconfig
	if [ $? -eq 0 ]
	then echo -e "Status : \033[1;32mSuccess\033[0m"
	else echo -e "Status : \033[1;31mFailed\033[0m"
	fi
fi

######################## Database installation #################

################### PostgreSQL initialization
echo "PostgreSQL : Configuration in progress"
su - postgres -c /usr/pgsql-9.2/bin/initdb

################### Configuring Database

######### PostgreSQL configuration files saving
if [ $? -eq 0 ]
then
	cp /var/lib/pgsql/9.2/data/postgresql.conf /var/lib/pgsql/9.2/data/postgresql.conf.save
	cp /var/lib/pgsql/9.2/data/pg_hba.conf /var/lib/pgsql/9.2/data/pg_hba.conf.save
######### PostgreSQL setting
	sed -i "60a\listen_addresses = \'\*\'\n" /var/lib/pgsql/9.2/data/postgresql.conf;
	sed -i "62a\port = 5432\n" /var/lib/pgsql/9.2/data/postgresql.conf;
	sed -i "86a\host all all samenet trust\n" /var/lib/pgsql/9.2/data/pg_hba.conf;
######### Postgresql service starting
	/usr/bin/systemctl enable postgresql-9.2.service
	/usr/sbin/service postgresql-9.2 restart
######### CAR database installing
	cd /tmp
	/usr/bin/wget -q https://team.inria.fr/stars/files/2015/01/carDB_20150129.zip
	/usr/bin/unzip -q carDB_20150129.zip
	chmod ugo+rw carDB_20150129.sql
if [ -f carDB_20150129.sql ]
then
	su - postgres -c "createdb --encoding=utf-8 --owner=postgres demcare"
	su - postgres -c "psql -Upostgres -ddemcare -p5432 -f /tmp/carDB_20150129.sql"
else
	echo -e "\033[1;31mCannot find the carDB_20150129.sql"
	echo -e "CAR database didn't installed\033[0m"
fi
fi
echo -e "\033[1;30mPostgreSQL : Configuration done\033[0m"

######### Exit
echo -e "\033[1;30mCAR Install Done\033[0m"
exit 0
